/****************************************************************************************************************
   Program: 120_create_nhc22_file.sas

   Purpose: This program reads in all monthly Nursing Home Compare files for 2022 (this includes January through
            November 2022 and January 2023, because there is no December 2022 file), limiting to variables needed to
            compare our calculation of facilities average daily census using the MDS (in a downstream program)
            or that might be useful for other data checks. The code retains the most recent monthly record for
            each facility (we do not combine records for facilities that shared a zip code and name or a zip code and
            street address).

   Input files: NH_ProviderInfo_Mmmyyyy.csv (Mmm = Jan, Feb, etc.
                                             yyyy = 2022, except for Dec which will be Jan 2023)

   Output files: nhc_2022.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

%let infile_pre = <input directory>;

libname out "<output directory>";

%let outfile = out.nhc_2022;

options validvarname=v7;

%macro imp_mth;

   %do i = 1 %to 12;

      %if &i. = 12 %then %do;
         %let mon = Jan;
         %let yr = 2023;
      %end;
      %else %do;
         %let yr = 2022;
         %if &i. = 1 %then %do;
            %let mon = Jan;
         %end;
         %else %if &i. = 2 %then %do;
            %let mon = Feb;
         %end;
         %else %if &i. = 3 %then %do;
            %let mon = Mar;
         %end;
         %else %if &i. = 4 %then %do;
            %let mon = Apr;
         %end;
         %else %if &i. = 5 %then %do;
            %let mon = May;
         %end;
         %else %if &i. = 6 %then %do;
            %let mon = Jun;
         %end;
         %else %if &i. = 7 %then %do;
            %let mon = Jul;
         %end;
         %else %if &i. = 8 %then %do;
            %let mon = Aug;
         %end;
         %else %if &i. = 9 %then %do;
            %let mon = Sep;
         %end;
         %else %if &i. = 10 %then %do;
            %let mon = Oct;
         %end;
         %else %if &i. = 11 %then %do;
            %let mon = Nov;
         %end;
      %end;

      %let infile = &infile_pre.\&yr.\NH_ProviderInfo_&mon.&yr..csv;

      proc import datafile = "&infile."
                  dbms = csv
                  out = nhc_2022_&i.(keep=Var1-Var18 Var21 Var22 where=(not missing(Var1)))
                  replace;
                  getnames=no;
                  datarow=2;
                  guessingrows=20000;
      run;

      data nhc_2022_&i.(drop=Var1-Var10 Var12-Var18 Var21 Var22);
         set nhc_2022_&i.(rename=(Var11 = nhc22_nmbr_crtfd_beds));

         length nhc22_legal_bus_name $ 70 nhc22_prov_name $ 51 nhc22_prov_addr $ 50 nhc22_ownership_type $ 38 
                nhc22_prov_cnty_name nhc22_prov_type $ 22 nhc22_prov_city $ 20 nhc22_prov_phone $ 10
                nhc22_ccn $ 6 nhc22_prov_zip $ 5 nhc22_prov_cnty_cd $ 3
                nhc22_prov_state nhc22_avg_nmbr_rsdnts_per_day_fn $ 2
                nhc22_resides_in_hospital nhc22_cont_care_rtrmnt_cmnty
                nhc22_hlth_insp_gt_2yrs_ago nhc22_changed_owner_lst12mnths $ 1;

         nhc22_month = &i.;

         nhc22_ccn = strip(Var1);
         nhc22_prov_name = strip(Var2);
         nhc22_prov_addr = strip(Var3);
         nhc22_prov_city = strip(Var4);
         nhc22_prov_zip = strip(Var6);
         nhc22_prov_state = strip(Var5);
         nhc22_prov_phone = strip(Var7);
         nhc22_prov_cnty_cd = strip(Var8);
         nhc22_prov_cnty_name = strip(Var9);
         nhc22_ownership_type = strip(Var10);
         Var12 = strip(Var12);
         nhc22_avg_nmbr_rsdnts_per_day_fn = strip(Var13);
         nhc22_prov_type = strip(Var14);
         nhc22_resides_in_hospital = strip(Var15);
         nhc22_legal_bus_name = strip(Var16);
         Var17 = strip(Var17);
         nhc22_cont_care_rtrmnt_cmnty = strip(Var18);
         nhc22_hlth_insp_gt_2yrs_ago = strip(Var21);
         nhc22_changed_owner_lst12mnths = strip(Var22);

         nhc22_avg_nmbr_rsdnts_per_day = input(Var12,8.);
         nhc22_date_first_approved = mdy(input(substrn(Var17,6,2),8.),
                                         input(substrn(Var17,9,2),8.),
                                         input(substrn(Var17,1,4),8.));

         format nhc22_date_first_approved date9.;
   
      run;

      proc sort data=nhc_2022_&i.;
         by nhc22_ccn;
      run;

   %end;

%mend imp_mth;

%imp_mth;

data nhc_2022(drop=nhc22_avg_nmbr_rsdnts_per_day)
     rsdnts_per_day(keep=nhc22_ccn nhc22_avg_nmbr_rsdnts_per_day);
   set nhc_2022_1-nhc_2022_12;
   by nhc22_ccn;

   if last.nhc22_ccn then output nhc_2022;
   output rsdnts_per_day;

run;

proc means data=rsdnts_per_day noprint;
   by nhc22_ccn;
   var nhc22_avg_nmbr_rsdnts_per_day;
   output out=avg_rsdnts_per_day(drop=_type_ _freq_) mean=nhc22_mthly_avg_dly_c;
run;

data &outfile.;
   merge nhc_2022 avg_rsdnts_per_day;
   by nhc22_ccn;
run;