/****************************************************************************************************************
   Program: 130_create_nhc24_file.sas

   Purpose: This program reads in the most recent publicly available month of Nursing Home Compare,
            including all variables available in the provider information file. The code constructs a numeric 
            variable related to ownership type.

   Input files: NH_ProviderInfo_Sep2024.csv

   Output files: nhc_2024.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

%let infile = <input directory>\NH_ProviderInfo_Sep2024.csv;

libname out "<output directory>";

%let outfile = out.nhc_2024;

options validvarname=v7;

proc import datafile = "&infile."
            dbms = csv
            out = nhc_2024(where=(not missing(Var1)))
            replace;
            getnames=no;
            datarow=2;
            guessingrows=20000;
run;

data nhc_2024(drop=Var1-Var10 Var14-Var16 Var18 Var20-Var26 Var99);
   set nhc_2024(rename=(Var11 = nhc24_nmbr_crtfd_beds
                        Var12 = nhc24_avg_nmbr_rsdnts_per_day
                        Var13 = nhc24_avg_nmbr_rsdnts_per_day_fn
                        Var17 = nhc24_date_first_approved
                        Var19 = nhc24_affiliated_entity_id
                        Var27 = nhc24_overall_rating
                        Var28 = nhc24_overall_rating_fn
                        Var29 = nhc24_hlth_inspection_rating
                        Var30 = nhc24_hlth_inspection_rating_fn
                        Var31 = nhc24_qm_rating
                        Var32 = nhc24_qm_rating_fn
                        Var33 = nhc24_long_stay_qm_rating
                        Var34 = nhc24_long_stay_qm_rating_fn
                        Var35 = nhc24_short_stay_qm_rating
                        Var36 = nhc24_short_stay_qm_rating_fn
                        Var37 = nhc24_staffing_rating
                        Var38 = nhc24_staffing_rating_fn
                        Var39 = nhc24_rptd_staffing_fn
                        Var40 = nhc24_phys_thrpst_staffing_fn
                        Var41 = nhc24_rptd_na_hrs_pppd
                        Var42 = nhc24_rptd_lpn_hrs_pppd
                        Var43 = nhc24_rptd_rn_hrs_pppd
                        Var44 = nhc24_rptd_lcnsd_hrs_pppd
                        Var45 = nhc24_rptd_tot_nrsg_hrs_pppd
                        Var46 = nhc24_wknd_tot_nrsg_hrs_pppd
                        Var47 = nhc24_wknd_rn_hrs_pppd
                        Var48 = nhc24_rptd_phys_thrpst_hrs_pppd
                        Var49 = nhc24_tot_nrsg_staff_turnover
                        Var50 = nhc24_tot_nrsg_staff_turnover_fn
                        Var51 = nhc24_rgstrd_nurse_turnover
                        Var52 = nhc24_rgstrd_nurse_turnover_fn
                        Var53 = nhc24_num_admin_left_nh
                        Var54 = nhc24_num_admin_left_nh_fn
                        Var55 = nhc24_nrsg_cm_index
                        Var56 = nhc24_nrsg_cm_index_ratio
                        Var57 = nhc24_cm_na_hrs_pppd
                        Var58 = nhc24_cm_lpn_hrs_pppd
                        Var59 = nhc24_cm_rn_hrs_pppd
                        Var60 = nhc24_cm_tot_nrsg_hrs_pppd
                        Var61 = nhc24_cm_wknd_tot_nrsg_hrs_pppd
                        Var62 = nhc24_adj_na_hrs_pppd
                        Var63 = nhc24_adj_lpn_hrs_pppd
                        Var64 = nhc24_adj_rn_hrs_pppd
                        Var65 = nhc24_adj_tot_nrsg_hrs_pppd
                        Var66 = nhc24_adj_wknd_tot_nrsg_hrs_pppd
                        Var67 = nhc24_rc1_std_survey_hlth_date
                        Var68 = nhc24_rc1_tot_nbr_hlth_dfcncs
                        Var69 = nhc24_rc1_nbr_std_hlth_dfcncs
                        Var70 = nhc24_rc1_nbr_cmplnt_hlth_dfcncs
                        Var71 = nhc24_rc1_hlth_dfcnc_score
                        Var72 = nhc24_rc1_nbr_hlth_revisits
                        Var73 = nhc24_rc1_hlth_revisit_score
                        Var74 = nhc24_rc1_tot_hlth_score
                        Var75 = nhc24_rc2_std_survey_hlth_date
                        Var76 = nhc24_rc2_tot_nbr_hlth_dfcncs
                        Var77 = nhc24_rc2_nbr_std_hlth_dfcncs
                        Var78 = nhc24_rc2_nbr_cmplnt_hlth_dfcncs
                        Var79 = nhc24_rc2_hlth_dfcnc_score
                        Var80 = nhc24_rc2_nbr_hlth_revisits
                        Var81 = nhc24_rc2_hlth_revisit_score
                        Var82 = nhc24_rc2_tot_hlth_score
                        Var83 = nhc24_rc3_std_survey_hlth_date
                        Var84 = nhc24_rc3_tot_nbr_hlth_dfcncs
                        Var85 = nhc24_rc3_nbr_std_hlth_dfcncs
                        Var86 = nhc24_rc3_nbr_cmplnt_hlth_dfcncs
                        Var87 = nhc24_rc3_hlth_dfcnc_score
                        Var88 = nhc24_rc3_nbr_hlth_revisits
                        Var89 = nhc24_rc3_hlth_revisit_score
                        Var90 = nhc24_rc3_tot_hlth_score
                        Var91 = nhc24_tot_wgtd_hlth_survey_score
                        Var92 = nhc24_nbr_fclty_rptd_incidents
                        Var93 = nhc24_nbr_substntd_complaints
                        Var94 = nhc24_nbr_infctn_cntl_citations
                        Var95 = nhc24_nmbr_of_fines
                        Var96 = nhc24_tot_amt_fines
                        Var97 = nhc24_nmbr_pmt_denials
                        Var98 = nhc24_tot_nmbr_penalties
                        Var100 = nhc24_latitude
                        Var101 = nhc24_longitude
                        Var102 = nhc24_geocoding_fn
                        Var103 = nhc24_processing_date));

   length nhc24_affiliated_entity_name $ 88 nhc24_location $ 72 nhc24_legal_bus_name $ 70 nhc24_prov_name $ 52
          nhc24_prov_addr $ 50 nhc24_ownership_type $ 38 nhc24_prov_cnty_name nhc24_prov_type $ 21
          nhc24_prov_city $ 20 nhc24_automatic_sprinklers $ 18 nhc24_special_focus_status $ 13
          nhc24_prov_phone $ 10 nhc24_resident_family_council $ 8 nhc24_ccn $ 6
          nhc24_prov_zip $ 5 nhc24_prov_cnty_cd $ 3 
          nhc24_prov_state $ 2
          nhc24_resides_in_hospital nhc24_cont_care_rtrmnt_cmnty nhc24_abuse_icon nhc24_hlth_insp_gt_2yrs_ago
          nhc24_changed_owner_lst12mnths $ 1;

   nhc24_ccn = strip(Var1);
   nhc24_prov_name = strip(Var2);
   nhc24_prov_addr = strip(Var3);
   nhc24_prov_city = strip(Var4);
   nhc24_prov_state = strip(Var5);
   nhc24_prov_zip = strip(Var6);
   nhc24_prov_phone = strip(Var7);
   nhc24_prov_cnty_cd = strip(Var8);
   nhc24_prov_cnty_name = strip(Var9);
   nhc24_ownership_type = strip(Var10);
   nhc24_prov_type = strip(Var14);
   nhc24_resides_in_hospital = strip(Var15);
   nhc24_legal_bus_name = strip(Var16);
   nhc24_affiliated_entity_name = strip(Var18);
   nhc24_cont_care_rtrmnt_cmnty = strip(Var20);
   nhc24_special_focus_status = strip(Var21);
   nhc24_abuse_icon = strip(Var22);
   nhc24_hlth_insp_gt_2yrs_ago = strip(Var23);
   nhc24_changed_owner_lst12mnths = strip(Var24);
   nhc24_resident_family_council = strip(Var25);
   nhc24_automatic_sprinklers = strip(Var26);
   nhc24_location = strip(Var99);

   if upcase(substrn(nhc24_ownership_type,1,10)) = "FOR PROFIT" then nhc24_owntype_sml = 1;
   else if upcase(substrn(nhc24_ownership_type,1,10)) = "NON PROFIT" then nhc24_owntype_sml = 2;
   else if upcase(substrn(nhc24_ownership_type,1,10)) = "GOVERNMENT" then nhc24_owntype_sml = 3;

   format nhc24_date_first_approved nhc24_rc1_std_survey_hlth_date nhc24_rc2_std_survey_hlth_date
          nhc24_rc3_std_survey_hlth_date nhc24_processing_date date9.;
   
run;

proc sort data=nhc_2024 out=&outfile.;
   by nhc24_ccn;
run;