/****************************************************************************************************************
   Program: 320_merge_final.sas

   Purpose: This program merges the previously merged LTC Focus and 2021 Nursing Home Compare data (from the 310 
            program) with the geocoded, most recent month of Nursing Home Compare data (from the 240 program). 
            It retains all facilities post-merge, even if they did not have a record in both input files, and 
            createas indicators for which file(s) the facility was found in.

   Input files: ltcf_nhc22.sas7bdat
                nhc_2024_w_rural.sas7bdat

   Output files: all_nh_facilities.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

libname in "<input directory>" access=readonly;
libname out "<output directory>";

%let in_nhc = in.nhc_2024_w_rural;
%let in_pre = in.ltcf_nhc22;
%let outfile = out.all_nh_facilities;

%let ltcf_yr = 2021;

data in_nhc24;
   set &in_nhc.(rename=(nhc24_ccn = ccn));
run;

data &outfile.;
   merge &in_pre.(in=a) in_nhc24(in=b);
   by ccn;

   in_nhc24 = b;

   if not a then do;
      in_ltcf = 0;
      in_nhc22 = 0;
   end;
            
run;