/****************************************************************************************************************
   Program Name: 400_process_mds.sas

   Description: Read in and prepare the prior and current year of MDS assessment data:
                   1. Limit to key variables
                   2. Identify beneficiaries with dementia
                   . Exclude assessments with missing CCNs
                   5. Flag assessments with a discharge status of died
                   6. Flag for exclusion assessments from SNF swing beds
				
   Input files: MDS_ASMT3_{prior year}.sas7bdat
				MDS_ASMT3_{current year}.sas7bdat

   Output files: _400_mds_{prior year}.sas7bdat
				 _400_mds_{current year}.sas7bdat
****************************************************************************************************************/
options validvarname=upcase mergenoby=error compress=yes;
options mprint symbolgen obs=max nocenter ls=154 ps=58 minoperator;

/* Macro to read-in and process MDS data in different years */
%macro process_mds;
%do yr = &prior_year. %to &year.;

	/* Read-in MDS data and retain a limited set of variables */
	data mds_initial_&yr.;
		set assmnt.mds_asmt3_&yr. (keep = bene_id asmt_id trgt_dt state_cd mds_crctn_stus_cd a0050_trans_type_cd orgnl_asmt_id
			 							  a0100b_cms_crtfctn_num a0200_prvdr_type_cd a0310f_entry_dschrg_cd a0800_gndr_cd a0900_birth_dt
										  a1000a_amrcn_indn_ak_ntv_cd a1000b_asn_cd a1000c_afrcn_amrcn_cd a1000d_hspnc_cd 
										  a1000e_ntv_hi_pcfc_islndr_cd a1000f_wht_cd i4200_alzhmr_cd i4800_dmnt_cd
										  a0310a_fed_obra_cd a0310b_pps_cd
								   );

		no_cms_crt_num = (missing(a0100b_cms_crtfctn_num));
		no_d_info = ((missing(i4200_alzhmr_cd) or i4200_alzhmr_cd = "-") and (missing(i4800_dmnt_cd) or i4800_dmnt_cd = "-"));

		dement = (i4200_alzhmr_cd = "1" or i4800_dmnt_cd = "1");
	run;
	
	/* Limit to assessments with non-missing CCNs and and create flags for whether the 
	   assessment is from a swing bed unit and for whether the beneficiary died 
	   in the facility */
	data &outdata._&yr.;
		set mds_initial_&yr.;
		where not missing(a0100b_cms_crtfctn_num);
		exclude = (a0200_prvdr_type_cd = "2");
		died = (a0310f_entry_dschrg_cd = "12");
	run;

%end;
%mend process_mds;
%process_mds;